#!/usr/bin/perl

# Created by ./mk_str_mod.pl on Tue Aug  7 12:44:34 WEST 2001

package Lingua::PT::VerbSuffixes ;
use Exporter ;
@ISA = qw(Exporter);
@EXPORT = qw( $verb_suffixes );
$verb_suffixes = <<EOSTR
a cpres,1,er,ir,r,uer,uir
a cpres,3,er,ir,r,uer,uir
a imp,1,r
a imp,3,r
a ivo,3,er,ir,r,uer,uir
a mdp,1,
a mdp,3,
ais cpres,5,edir,enir,entir,er,ir,r,uer,uir
am cpres,6,er,ir,r,uer,uir
am imp,6,r
am ivo,6,er,ir,r,uer,uir
am mdp,6,
am perf,6,
amos cpres,4,er,ir,r,uer,uir
amos ivo,4,er,ir,r,uer,uir
arei fut,1,razer
as cpres,2,er,ir,r,uer,uir
as imp,2,r
as mdp,2,
ce cpres,1,ar
ce cpres,3,ar
ce ivo,3,ar
cei perf,1,ar
ceis cpres,5,ar
cem cpres,6,ar
cem ivo,6,ar
cemos cpres,4,ar
cemos ivo,4,ar
ces cpres,2,ar
cto pp,1,ioar
de ivo,3,r
de ivo,5,r
deie cpres,1,ndiar
des cfut,5,
des pres,5,r
do pp,1,r,scer
e cpres,1,ar
e cpres,3,ar
e ivo,2,ir
e ivo,3,ar
e pp,1,ar
e pres,3,ir
ecto pp,1,igir
edvais cpres,5,advir
ei fut,1,
ei perf,1,ar
ei pres,1,aber,aver
eia ivo,2,iar
eia pres,3,iar
eiam pres,6,iar
eias pres,2,iar
eie cpres,1,iar
eie cpres,3,iar
eie ivo,3,iar
eieis cpres,5,iar
eiem cpres,6,iar
eiem ivo,6,iar
eies cpres,2,iar
eio perf,3,ir
eio pres,1,iar
eirdes cfut,5,ar
eis cpres,5,ar
eis fut,5,
eito pp,1,azer
eja cpres,1,ar
eja cpres,3,ar
ejais cpres,5,ar
ejam cpres,6,ar
ejam ivo,6,ar
ejamos cpres,4,ar
ejamos ivo,4,ar
ejas cpres,2,ar
em cfut,6,
em cpres,6,ar
em ivo,6,ar
em pres,3,ir
em pres,6,ir,r
emos cpres,4,ar
emos fut,4,
emos ivo,4,ar
emos perf,4,ar,r
enha cpres,1,ir
enha cpres,3,ir
enha ivo,3,ir
enhais cpres,5,ir
enham cpres,6,ir
enham ivo,6,ir
enhamos cpres,4,ir
enhamos ivo,4,ir
enhas cpres,2,ir
enhas ivo,2,ir
enho pres,1,ir
ens pres,2,ir
envais cpres,5,onvir
er cfut,1,ar,r
er cfut,3,ar,r
era imp,1,ser
era imp,3,ser
era mdp,1,ar,r
era mdp,3,ar,r
eram imp,6,ser
eram mdp,6,ar,r
eram perf,6,ar,r
eras imp,2,ser
eras mdp,2,ar,r
erem cfut,6,ar,r
eres cfut,2,ar,r
ermos cfut,4,ar,r
erto pp,1,rir
es cfut,2,
es cpres,2,ar
es pres,2,ir
esse cimp,1,ar,r
esse cimp,3,ar,r
essem cimp,6,ar,r
esses cimp,2,ar,r
esso pp,1,imir,itir
este perf,2,ar,r
estes perf,5,ar
eu perf,3,ar
evais cpres,5,over
eve perf,3,ar
ez perf,3,azer
foi perf,3,ir,ser
fomos perf,4,ir,ser
for cfut,1,ir,ser
for cfut,3,ir,ser
fora mdp,1,ser
fora mdp,3,ser
foram cfut,6,ir
foram mdp,6,ser
foram perf,6,ir,ser
foras mdp,2,ser
fordes cfut,5,ir,ser
forem cfut,6,ser
fores cfut,2,ir,ser
formos cfut,4,ir,ser
fosse cimp,1,ir,ser
fosse cimp,3,ir,ser
fossem cimp,6,ir,ser
fosses cimp,2,ir,ser
foste perf,2,ir,ser
fostes perf,5,ir,ser
fui perf,1,ir,ser
framos mdp,4,ser
freis mdp,5,ser
fsseis cimp,5,ir,ser
fssemos cimp,4,ir,ser
ga cpres,1,zer
ga cpres,3,zer
ga ivo,3,zer
gais cpres,5,zer
gam cpres,6,zer
gam ivo,6,zer
gamos cpres,4,zer
gamos ivo,4,zer
gas cpres,2,zer
gei ivo,5,zer
go pres,1,zer
grato pp,1,agradecer
ha cpres,1,er
ha cpres,3,er
ha ivo,3,er
hais cpres,5,er
ham cpres,6,er
ham ivo,6,er
hamos cpres,4,er
hamos ivo,4,er
has cpres,2,er
ho pres,1,er
i ivo,2,ar
i ivo,5,r
i perf,1,er
i pres,3,ar
ia cond,1,
ia cond,3,
ia cpres,1,r
ia cpres,3,r
ia imp,1,er
ia imp,3,er
ia ivo,2,ar
ia pres,3,ar
iais cpres,5,r
iam cond,6,
iam cpres,6,r
iam imp,6,er
iam ivo,6,r
iam pres,6,ar
iamos cpres,4,r
iamos ivo,4,r
ias cond,2,
ias cpres,2,r
ias imp,2,er
ias pres,2,ar
iba cpres,1,ber
iba cpres,3,ber
iba ivo,3,ber
ibais cpres,5,ber
ibam cpres,6,ber
ibam ivo,6,ber
ibamos cpres,4,ber
ibamos ivo,4,ber
ibas cpres,2,ber
ibo pres,1,ber
icta cpres,1,ectir
icta cpres,3,ectir
icta ivo,3,ectir
ictais cpres,5,ectir
ictam cpres,6,ectir
ictam ivo,6,ectir
ictamos cpres,4,ectir
ictamos ivo,4,ectir
ictas cpres,2,ectir
icto pp,1,encer
icto pres,1,ectir
ida cpres,1,edir
ida cpres,3,edir
ida ivo,3,edir
idais cpres,5,edir
idam cpres,6,edir
idam ivo,6,edir
idamos cpres,4,edir
idamos ivo,4,edir
idas cpres,2,edir
ide ivo,2,edir
ide pres,3,edir
idem pres,6,edir
ides pres,2,edir
idis pres,5,edir
ido pp,1,er
ido pres,1,edir
ie ivo,3,ar
iem ivo,6,ar
iga cpres,1,eguir
iga cpres,3,eguir
iga ivo,3,eguir
igais cpres,5,eguir
igam cpres,6,eguir
igam ivo,6,eguir
igamos cpres,4,eguir
igamos ivo,4,eguir
igas cpres,2,eguir
igo pres,1,eguir
ila cpres,1,elir
ila cpres,3,elir
ila ivo,3,elir
ilais cpres,5,elir,ler
ilam cpres,6,elir
ilam ivo,6,elir
ilamos cpres,4,elir
ilamos ivo,4,elir
ilas cpres,2,elir
ilo pres,1,elir
imos perf,4,er
ina cpres,1,enir
ina cpres,3,enir
ina ivo,3,enir
inam cpres,6,enir
inam ivo,6,enir
inamos cpres,4,enir
inamos ivo,4,enir
inas cpres,2,enir
ine ivo,2,enir
ine pres,3,enir
inem pres,6,enir
ines pres,2,enir
inha imp,1,er
inha imp,3,er
inham imp,6,er
inhas imp,2,er
inis pres,5,enir
ino pres,1,enir
inta cpres,1,entir
inta cpres,3,entir
inta ivo,3,entir
intais cpres,5,entir
intam cpres,6,entir
intam ivo,6,entir
intamos cpres,4,entir
intamos ivo,4,entir
intas cpres,2,entir
inti ivo,5,entir
into pres,1,entir
io pres,1,ar,r
ir cfut,1,er
ir cfut,3,er
ira cpres,1,erir,rer
ira cpres,3,erir,rer
ira ivo,3,erir,rer
ira mdp,1,er
ira mdp,3,er
irais cpres,5,erir,rer
iram cpres,6,erir,rer
iram ivo,6,erir,rer
iram mdp,6,er
iram perf,6,er
iramos cpres,4,erir,rer
iramos ivo,4,erir,rer
iras cpres,2,erir,rer
iras mdp,2,er
irdes cfut,5,er
irem cfut,6,er
ires cfut,2,er
irmos cfut,4,er
iro pres,1,erir,rer
irta cpres,1,ertir
irta cpres,3,ertir
irta ivo,3,ertir
irtais cpres,5,ertir
irtam cpres,6,ertir
irtam ivo,6,ertir
irtamos cpres,4,ertir
irtamos ivo,4,ertir
irtas cpres,2,ertir
irto pres,1,ertir
irva cpres,1,ervir
irva cpres,3,ervir
irva ivo,3,ervir
irvais cpres,5,ervir
irvam cpres,6,ervir
irvam ivo,6,ervir
irvamos cpres,4,ervir
irvamos ivo,4,ervir
irvas cpres,2,ervir
irvo pres,1,ervir
is perf,1,erer
is perf,3,erer
is pres,2,ar
is pres,5,r
isemos perf,4,erer
iser cfut,1,erer
iser cfut,3,erer
isera mdp,1,erer
isera mdp,3,erer
iseram mdp,6,erer
iseram perf,6,erer
iseras mdp,2,erer
iserdes cfut,5,erer
iserem cfut,6,erer
iseres cfut,2,erer
isermos cfut,4,erer
isesse cimp,1,erer
isesse cimp,3,erer
isessem cimp,6,erer
isesses cimp,2,erer
iseste perf,2,erer
isse cimp,1,er
isse cimp,3,er
issem cimp,6,er
isses cimp,2,er
isso pp,1,eter
ista cpres,1,estir
ista cpres,3,estir
ista ivo,3,estir
istais cpres,5,estir
istam cpres,6,estir
istam ivo,6,estir
istamos cpres,4,estir
istamos ivo,4,estir
istas cpres,2,estir
iste perf,2,er
isto pp,1,er
isto pres,1,estir
isramos mdp,4,erer
isssemos cimp,4,erer
isreis mdp,5,erer
issseis cimp,5,erer
ita cpres,1,etir
ita cpres,3,etir
ita ivo,3,etir
itais cpres,5,etir
itam cpres,6,etir
itam ivo,6,etir
itamos cpres,4,etir
itamos ivo,4,etir
itas cpres,2,etir
ito pp,1,ever,ger
ito pres,1,etir
iu perf,3,er
ive perf,1,ar,er
ivemos perf,4,ar,er
iver cfut,1,ar,er
iver cfut,3,ar,er
ivera mdp,1,ar,er
ivera mdp,3,ar,er
iveram mdp,6,er
iveram perf,6,ar,er
iveras mdp,2,ar,er
iverdes cfut,5,ar,er
iverem cfut,6,ar,er
iveres cfut,2,ar,er
ivermos cfut,4,ar,er
iverm mdp,6,ar
ivesse cimp,1,ar,er
ivesse cimp,3,ar
ivessem cimp,6,ar,er
ivesses cimp,2,ar,er
iveste perf,2,ar,er
ivestes perf,5,ar,er
ivramos mdp,4,ar,er
ivreis mdp,5,ar,er
ivsseis cimp,4,er
ivsseis cimp,5,ar
ivssemos cimp,3,er
ivssemos cimp,4,ar
ivsseis cimp,5,er
iz perf,1,azer
izemos perf,4,azer
izer cfut,1,azer
izer cfut,3,azer
izera mdp,1,azer
izera mdp,3,azer
izeram mdp,6,azer
izeram perf,6,azer
izeras mdp,2,azer
izerdes cfut,5,azer
izerem cfut,6,azer
izeres cfut,2,azer
izermos cfut,4,azer
izesse cimp,1,azer
izesse cimp,3,azer
izessem cimp,6,azer
izesses cimp,2,azer
izeste perf,2,azer
izramos mdp,4,azer
izreis mdp,5,azer
izsseis cimp,5,azer
izssemos cimp,4,azer
ia cpres,1,uvir
ia cpres,3,uvir
ia ivo,3,uvir
iais cpres,5,uvir
iam cpres,6,uvir
iam ivo,6,uvir
iamos cpres,4,uvir
iamos ivo,4,uvir
ias cpres,2,uvir
io pres,1,uvir
ja cpres,1,ger,gir,r,ver
ja cpres,3,ger,gir,r,ver
ja ivo,3,ger,gir,r,ver
jais cpres,5,ger,gir,r,ver
jam cpres,6,ger,gir,r,ver
jam ivo,6,ger,gir,r,ver
jamos cpres,4,ger,gir,r,ver
jamos ivo,4,ger,gir,r,ver
jas cpres,2,ger,gir,r,ver
jas ivo,2,ver
jo pres,1,ger,gir,r
jueado pp,1,guear
jueai ivo,5,guear
jueais pres,5,guear
jueamos perf,4,guear
jueamos pres,4,guear
jueando grd,1,guear
juear cfut,1,guear
juear cfut,3,guear
jueara mdp,1,guear
jueara mdp,3,guear
juearam mdp,6,guear
juearam perf,6,guear
juearas mdp,2,guear
jueardes cfut,5,guear
juearei fut,1,guear
jueareis fut,5,guear
juearem cfut,6,guear
juearemos fut,4,guear
jueares cfut,2,guear
juearia cond,1,guear
juearia cond,3,guear
jueariam cond,6,guear
juearias cond,2,guear
juearmos cfut,4,guear
juear fut,3,guear
juears fut,2,guear
juearo fut,6,guear
juearamos cond,4,guear
jueareis cond,5,guear
jueasse cimp,1,guear
jueasse cimp,3,guear
jueassem cimp,6,guear
jueasses cimp,2,guear
jueaste perf,2,guear
jueastes perf,5,guear
jueava imp,1,guear
jueava imp,3,guear
jueavam imp,6,guear
jueavas imp,2,guear
juee cpres,1,guear
juee cpres,3,guear
jueei perf,1,guear
jueeis cpres,5,guear
jueem cpres,6,guear
jueemos cpres,4,guear
jueemos ivo,4,guear
juees cpres,2,guear
jueia ivo,2,guear
jueia pres,3,guear
jueiam pres,6,guear
jueias pres,2,guear
jueie ivo,3,guear
jueiem ivo,6,guear
jueio pres,1,guear
jueou perf,3,guear
jueramos mdp,4,guear
juereis mdp,5,guear
juesseis cimp,5,guear
juessemos cimp,4,guear
juevamos imp,4,guear
jueveis imp,5,guear
luto pp,1,ver
m ivo,2,r
m perf,1,r
m perf,6,r
m pres,3,r
m pres,6,r
mirdes cfut,5,r
mos cfut,4,
mos perf,4,r
mos pres,4,r
msseis cimp,5,r
nde ivo,5,r
ndes pres,5,r
ndo grd,1,r
ndo pp,1,r
nha cpres,1,r
nha cpres,3,r
nha imp,1,r
nha imp,3,r
nha ivo,3,r
nhais cpres,5,r
nham cpres,6,r
nham imp,6,r
nham ivo,6,r
nhamos cpres,4,r
nhamos ivo,4,r
nhas cpres,2,r
nhas imp,2,r
nho pres,1,r
ns pres,2,r
o pp,1,ar,ivar
o pres,1,ar,er,ir,r,uer,uir
obe ivo,2,ubir
obe pres,3,ubir
obem pres,6,ubir
obes pres,2,ubir
oem pres,6,uir
oge ivo,2,ugir
oge pres,3,ugir
ogem pres,6,ugir
oges pres,2,ugir
oiemos cpres,4,iar
oiemos ivo,4,iar
ois pres,5,er
omos pres,4,er,r
onde ivo,5,r
ondes pres,5,r
ondo grd,1,r
onha cpres,1,r
onha cpres,3,r
onha ivo,3,r
onhais cpres,5,r
onham cpres,6,r
onham ivo,6,r
onhamos cpres,4,r
onhamos ivo,4,r
onhas cpres,2,r
onho pres,1,r
orei fut,1,r
oreis fut,5,r
oremos fut,4,r
oria cond,1,r
oria cond,3,r
oriam cond,6,r
orias cond,2,r
orto pp,1,atar
or fut,3,r
ors fut,2,r
oro fut,6,r
oramos cond,4,r
oreis cond,5,r
osto pp,1,r
ou perf,3,ar
ou pres,1,ar,er
oube perf,1,aber
oube perf,3,aber
oubemos perf,4,aber
ouber cfut,1,aber
ouber cfut,3,aber
oubera mdp,1,aber
oubera mdp,3,aber
ouberam mdp,6,aber
ouberam perf,6,aber
ouberas mdp,2,aber
ouberdes cfut,5,aber
ouberem cfut,6,aber
ouberes cfut,2,aber
oubermos cfut,4,aber
oubesse cimp,1,aber
oubesse cimp,3,aber
oubessem cimp,6,aber
oubesses cimp,2,aber
oubeste perf,2,aber
oubestes perf,5,aber
oubeu perf,3,aber
oubramos mdp,4,aber
oubssemos cimp,4,aber
oubreis mdp,5,aber
oubsseis cimp,5,aber
ouve perf,1,aver
ouve perf,3,aver
ouvemos perf,4,aver
ouver cfut,1,aver
ouver cfut,3,aver
ouvera mdp,1,aver
ouvera mdp,3,aver
ouveram mdp,6,aver
ouveram perf,6,aver
ouveras mdp,2,aver
ouverdes cfut,5,aver
ouverem cfut,6,aver
ouveres cfut,2,aver
ouvermos cfut,4,aver
ouvesse cimp,1,aver
ouvesse cimp,3,aver
ouvessem cimp,6,aver
ouvesses cimp,2,aver
ouveste perf,2,aver
ouvestes perf,5,aver
ouvramos mdp,4,aver
ouvreis mdp,5,aver
ouvsseis cimp,5,aver
ouvssemos cimp,4,aver
ouxe perf,1,azer
ouxemos perf,4,azer
ouxer cfut,1,azer
ouxer cfut,3,azer
ouxera mdp,1,azer
ouxera mdp,3,azer
ouxeram mdp,6,azer
ouxeram perf,6,azer
ouxeras mdp,2,azer
ouxerdes cfut,5,azer
ouxerem cfut,6,azer
ouxeres cfut,2,azer
ouxermos cfut,4,azer
ouxesse cimp,1,azer
ouxesse cimp,3,azer
ouxessem cimp,6,azer
ouxesses cimp,2,azer
ouxeste perf,2,azer
ouxestes perf,5,azer
ouxeu perf,3,azer
ouxramos mdp,4,azer
ouxreis mdp,5,azer
ouxsseis cimp,5,azer
ouxssemos cimp,4,azer
que cpres,1,car
que cpres,3,car
que ivo,3,car
queado pp,1,cear
queai ivo,5,cear
queais pres,5,cear
queamos perf,4,cear
queamos pres,4,cear
queando grd,1,cear
quear cfut,1,cear
quear cfut,3,cear
queara mdp,1,cear
queara mdp,3,cear
quearam mdp,6,cear
quearam perf,6,cear
quearas mdp,2,cear
queardes cfut,5,cear
quearei fut,1,cear
queareis fut,5,cear
quearem cfut,6,cear
quearemos fut,4,cear
queares cfut,2,cear
quearia cond,1,cear
quearia cond,3,cear
queariam cond,6,cear
quearias cond,2,cear
quearmos cfut,4,cear
quear fut,3,cear
quears fut,2,cear
quearo fut,6,cear
quearamos cond,4,cear
queareis cond,5,cear
queasse cimp,1,cear
queasse cimp,3,cear
queassem cimp,6,cear
queasses cimp,2,cear
queaste perf,2,cear
queastes perf,5,cear
queava imp,1,cear
queava imp,3,cear
queavam imp,6,cear
queavas imp,2,cear
quee cpres,1,cear
quee cpres,3,cear
queei perf,1,cear
queeis cpres,5,cear
queem cpres,6,cear
queemos cpres,4,cear
queemos ivo,4,cear
quees cpres,2,cear
quei perf,1,car
queia ivo,2,cear
queia pres,3,cear
queiam pres,6,cear
queias pres,2,cear
queie ivo,3,cear
queiem ivo,6,cear
queio pres,1,cear
queis cpres,5,car
quem cpres,6,car
quem ivo,6,car
quemos cpres,4,car
quemos ivo,4,car
queou perf,3,cear
ques cpres,2,car
queramos mdp,4,cear
quereis mdp,5,cear
quesseis cimp,5,cear
quessemos cimp,4,cear
quevamos imp,4,cear
queveis imp,5,cear
r cfut,1,ir
r cfut,3,ir
rdes cfut,5,ir
rei fut,1,zer
reis fut,5,zer
rem cfut,6,ir
remos fut,4,zer
res cfut,2,ir
ria cond,1,zer
ria cond,3,zer
riam cond,6,zer
rias cond,2,zer
rmos cfut,4,ir
r fut,3,zer
rs fut,2,zer
ro fut,6,zer
ramos cond,4,zer
reis cond,5,zer
s perf,3,r
s pres,2,r
s pres,5,r
so pp,1,der,gir,ir,nder,ter
ssa cpres,1,der
ssa cpres,3,der
ssa ivo,3,der
ssais cpres,5,der
ssam cpres,6,der
ssam ivo,6,der
ssamos cpres,4,der
ssamos ivo,4,der
ssas cpres,2,der
sse cimp,1,ir,r
sse cimp,3,ir,r
sse perf,1,zer
sse perf,3,zer
ssem cimp,6,ir,r
ssemos perf,4,zer
sser cfut,1,zer
sser cfut,3,zer
sseram perf,6,zer
sserdes cfut,5,zer
sserem cfut,6,zer
sseres cfut,2,zer
ssermos cfut,4,zer
sses cimp,2,ir,r
ssesse cimp,1,zer
ssesse cimp,3,zer
ssessem cimp,6,zer
ssesses cimp,2,zer
sseste perf,2,zer
sso pres,1,der
sssseis cimp,5,zer
ssssemos cimp,4,zer
ste perf,2,r
stes perf,5,r
sto pp,1,r
to pp,1,der,gar,gir,guir,ir,mper,rer,ver,zer
u perf,3,r
ubra cpres,1,obrir
ubra cpres,3,obrir
ubrais cpres,5,obrir
ubram cpres,6,obrir
ubramos cpres,4,obrir
ubras cpres,2,obrir
ubro pres,1,obrir
ude perf,1,oder
udemos perf,4,oder
uder cfut,1,oder
uder cfut,3,oder
udera mdp,1,oder
udera mdp,3,oder
uderam mdp,6,oder
uderam perf,6,oder
uderas mdp,2,oder
uderdes cfut,5,oder
uderem cfut,6,oder
uderes cfut,2,oder
udermos cfut,4,oder
udesse cimp,1,oder
udesse cimp,3,oder
udessem cimp,6,oder
udesses cimp,2,oder
udeste perf,2,oder
udssemos cimp,4,oder
udramos mdp,4,oder
udreis mdp,5,oder
udsseis cimp,5,oder
ue cpres,1,ar
ue cpres,3,ar
ue ivo,3,ar
ue pp,1,ar
uei perf,1,ar
ueis cpres,5,ar
uem cpres,6,ar
uem ivo,6,ar
uemos cpres,4,ar
uemos ivo,4,ar
ues cpres,2,ar
ula cpres,1,olir
ula cpres,3,olir
ulais cpres,5,olir
ulam cpres,6,olir
ulamos cpres,4,olir
ulas cpres,2,olir
ulo pres,1,olir
ulso pp,1,elir
unha imp,1,or,r
unha imp,3,or,r
unham imp,6,or,r
unhas imp,2,or,r
upto pp,1,omper
urma cpres,1,ormir
urma cpres,3,ormir
urmais cpres,5,ormir
urmam cpres,6,ormir
urmamos cpres,4,ormir
urmas cpres,2,ormir
urmo pres,1,ormir
urso pp,1,orrer
us perf,1,or,r
usemos perf,4,or,r
user cfut,1,or,r
user cfut,3,or,r
usera mdp,1,or,r
usera mdp,3,or,r
useram mdp,6,or,r
useram perf,6,or,r
useras mdp,2,or,r
userdes cfut,5,or,r
userem cfut,6,or,r
useres cfut,2,or,r
usermos cfut,4,or,r
usesse cimp,1,or,r
usesse cimp,3,or,r
usessem cimp,6,or,r
usesses cimp,2,or,r
useste perf,2,or,r
usestes perf,5,or,r
usramos mdp,4,or,r
usreis mdp,5,or,r
ussseis cimp,5,r
usssemos cimp,4,or,r
usseis cimp,5,or
va imp,1,r
va imp,3,r
vades cpres,5,ir
vai ivo,2,ir
vai pres,3,ir
vais pres,2,ir
vam imp,6,r
vamos cpres,4,ir
vamos ivo,4,ir
vamos pres,4,ir
vas imp,2,r
ve perf,3,r
vou pres,1,ir
v cpres,1,ir
v cpres,3,ir
vs cpres,2,ir
vo cpres,6,ir
vo ivo,6,ir
vo pres,6,ir
 fut,3,
 ivo,2,ar
 pres,3,ar,aver
ramos mdp,4,ar
reis mdp,5,ar
s fut,2,
s pres,2,ar,aver
sseis cimp,5,air,ar
ssemos cimp,4,air,ar
vamos imp,4,ar
veis imp,5,ar
o fut,6,
o pres,6,ar,aver,er
a cpres,1,cer,cir,dir,vir,zer
a cpres,3,cer,cir,dir,vir,zer
a ivo,3,cer,cir,dir,zer
ais cpres,5,cer,cir,dir,vir,zer
am cpres,6,cer,cir,dir,vir,zer
am ivo,6,cer,cir,dir,vir,zer
amos cpres,4,cer,cir,dir,vir,zer
amos ivo,4,cer,cir,dir,vir,zer
as cpres,2,cer,cir,dir,vir,zer
auteado pp,1,cautear
auteai ivo,5,cautear
auteais pres,5,cautear
auteamos perf,4,cautear
auteamos pres,4,cautear
auteando grd,1,cautear
autear cfut,1,cautear
autear cfut,3,cautear
auteara mdp,1,cautear
auteara mdp,3,cautear
autearam mdp,6,cautear
autearam perf,6,cautear
autearas mdp,2,cautear
auteardes cfut,5,cautear
autearei fut,1,cautear
auteareis fut,5,cautear
autearem cfut,6,cautear
autearemos fut,4,cautear
auteares cfut,2,cautear
autearia cond,1,cautear
autearia cond,3,cautear
auteariam cond,6,cautear
autearias cond,2,cautear
autearmos cfut,4,cautear
autear fut,3,cautear
autears fut,2,cautear
autearo fut,6,cautear
autearamos cond,4,cautear
auteareis cond,5,cautear
auteasse cimp,1,cautear
auteasse cimp,3,cautear
auteassem cimp,6,cautear
auteasses cimp,2,cautear
auteaste perf,2,cautear
auteastes perf,5,cautear
auteava imp,1,cautear
auteava imp,3,cautear
auteavam imp,6,cautear
auteavas imp,2,cautear
autee cpres,1,cautear
autee cpres,3,cautear
auteei perf,1,cautear
auteeis cpres,5,cautear
auteem cpres,6,cautear
auteemos cpres,4,cautear
auteemos ivo,4,cautear
autees cpres,2,cautear
auteia ivo,2,cautear
auteia pres,3,cautear
auteiam pres,6,cautear
auteias pres,2,cautear
auteie ivo,3,cautear
auteiem ivo,6,cautear
auteio pres,1,cautear
auteou perf,3,cautear
auteramos mdp,4,cautear
autereis mdp,5,cautear
autesseis cimp,5,cautear
autessemos cimp,4,cautear
autevamos imp,4,cautear
auteveis imp,5,cautear
o pres,1,cer,cir,dir,vir,zer
oa ivo,2,coar
oa pres,3,coar
oado pp,1,coar
oai ivo,5,coar
oais pres,5,coar
oam pres,6,coar
oamos perf,4,coar
oamos pres,4,coar
oando grd,1,coar
oar cfut,1,coar
oar cfut,3,coar
oara mdp,1,coar
oara mdp,3,coar
oaram mdp,6,coar
oaram perf,6,coar
oaras mdp,2,coar
oardes cfut,5,coar
oarei fut,1,coar
oareis fut,5,coar
oarem cfut,6,coar
oaremos fut,4,coar
oares cfut,2,coar
oaria cond,1,coar
oaria cond,3,coar
oariam cond,6,coar
oarias cond,2,coar
oarmos cfut,4,coar
oar fut,3,coar
oars fut,2,coar
oaro fut,6,coar
oaramos cond,4,coar
oareis cond,5,coar
oas pres,2,coar
oasse cimp,1,coar
oasse cimp,3,coar
oassem cimp,6,coar
oasses cimp,2,coar
oaste perf,2,coar
oastes perf,5,coar
oava imp,1,coar
oava imp,3,coar
oavam imp,6,coar
oavas imp,2,coar
oe cpres,1,coar
oe cpres,3,coar
oe ivo,3,coar
oei perf,1,coar
oeis cpres,5,coar
oem cpres,6,coar
oem ivo,6,coar
oemos cpres,4,coar
oemos ivo,4,coar
oes cpres,2,coar
oo pres,1,coar
oou perf,3,coar
oramos mdp,4,coar
oreis mdp,5,coar
osseis cimp,5,coar
ossemos cimp,4,coar
ovamos imp,4,coar
oveis imp,5,coar
 pres,3,ser
ja ivo,3,ar
m ivo,2,er
m pres,3,er
ns pres,2,er
ramos imp,4,ser
ramos mdp,4,ar,r
reis imp,5,ser
s pres,2,ser
ssemos cimp,4,r
 cpres,1,ar
 cpres,3,ar
 ivo,2,er
 ivo,3,ar
 pres,3,er
em cpres,6,ar
em ivo,6,ar
em pres,6,er
ia ivo,3,er
m pres,6,er,ir
mos cpres,4,ar
ramos mdp,4,er
reis mdp,5,er
s cpres,2,ar
s pres,2,er
sseis cimp,5,ar,er
ssemos cimp,4,ar,er
 ivo,5,ir
 perf,1,er,ir
a imp,1,er,ir
a imp,3,er,ir
am imp,6,er,ir
amos cond,3,
amos cond,4,
amos cpres,4,ir
amos imp,4,er,ir
as imp,2,er,ir
do pp,1,er,ir
eis cond,4,
eis cond,5,
eis cpres,5,ir
eis imp,5,er,ir
mos perf,4,ir
mos pres,4,ir
nhamos imp,4,er,ir
nheis imp,5,er
r cfut,1,ir
r cfut,3,ir
ra mdp,1,ir
ra mdp,3,ir
ram mdp,6,ir
ram perf,6,ir
ramos mdp,4,er,ir
ras mdp,2,ir
rdes cfut,5,ir
reis mdp,5,er,ir
rem cfut,6,ir
res cfut,2,ir
rmos cfut,4,ir
s pres,2,er
s pres,5,ir
sse cimp,1,ir
sse cimp,3,ir
sseis cimp,5,ir
ssem cimp,6,ir
ssemos cimp,4,ir
sses cimp,2,ir
ste perf,2,ir
stes perf,5,ir
sseis cimp,5,er
ssemos cimp,4,er
i ivo,2,oer
i pres,3,oer,uir
ia ivo,2,iar,oiar
ia pres,3,iar,oiar
iais pres,5,iar,oiar
iam pres,6,iar,oiar
iamos pres,4,iar,oiar
ias pres,2,iar,oiar
ie cpres,1,iar,oiar
ie cpres,3,iar,oiar
ie ivo,3,iar,oiar
ieis cpres,5,iar
iem cpres,6,iar,oiar
iem ivo,6,iar,oiar
ies cpres,2,iar,oiar
io pres,1,iar,oiar
is pres,2,uir
de perf,3,oder
s perf,3,or
e ivo,2,or,r
e pres,3,or,r
em pres,6,or,r
es pres,2,or,r
e cpres,1,uar
e cpres,3,uar
e ivo,3,uar
eis cpres,5,uar
em cpres,6,uar
em ivo,6,uar
emos cpres,4,uar
es cpres,2,uar
nhamos imp,4,or,r
nheis imp,5,or,r

EOSTR
    ;
1 ;
